@@ -29,7 +29,7 @@ CONF = cfg.CONF
 
 RESOURCE_STATUSES = ['ACTIVE', 'PENDING', 'DELETED', 'ERROR']
 RECORD_TYPES = ['A', 'AAAA', 'CNAME', 'MX', 'SRV', 'TXT', 'SPF', 'NS', 'PTR',
-                'SSHFP']
+                'SSHFP', 'SOA']
 TASK_STATUSES = ['ACTIVE', 'PENDING', 'DELETED', 'ERROR', 'COMPLETE']
 TSIG_ALGORITHMS = ['hmac-md5', 'hmac-sha1', 'hmac-sha224', 'hmac-sha256',
                    'hmac-sha384', 'hmac-sha512']
@@ -47,7 +47,7 @@ SERVICE_STATES = [
 metadata = MetaData()
 
 # TODO(Federico) some default column values are not needed because we
-# explicitely set the value on record insertion. Having default values could
+# explicitly set the value on record insertion. Having default values could
 # hide bugs.
 
 
@@ -128,7 +128,7 @@ zones = Table('zones', metadata,
     Column('expire', Integer, default=CONF.default_soa_expire, nullable=False),
     Column('minimum', Integer, default=CONF.default_soa_minimum,
            nullable=False),
-    Column('status', Enum(name='resource_statuses', *RESOURCE_STATUSES),
+    Column('status', Enum(name='zones_resource_statuses', *RESOURCE_STATUSES),
            nullable=False, server_default='PENDING', default='PENDING'),
     Column('parent_zone_id', UUID, default=None, nullable=True),
     Column('action', Enum(name='actions', *ACTIONS),
@@ -226,7 +226,8 @@ records = Table('records', metadata,
            nullable=True),
     Column('managed_resource_id', UUID, default=None, nullable=True),
     Column('managed_tenant_id', String(36), default=None, nullable=True),
-    Column('status', Enum(name='resource_statuses', *RESOURCE_STATUSES),
+    Column('status', Enum(name='records_resource_statuses',
+                          *RESOURCE_STATUSES),
            server_default='PENDING', default='PENDING', nullable=False),
     Column('action', Enum(name='actions', *ACTIONS),
            default='CREATE', server_default='CREATE', nullable=False),
@@ -420,7 +421,8 @@ zone_transfer_requests = Table('zone_transfer_requests', metadata,
     Column("description", String(255), nullable=False),
     Column("tenant_id", String(36), default=None, nullable=False),
     Column("target_tenant_id", String(36), default=None, nullable=True),
-    Column("status", Enum(name='resource_statuses', *TASK_STATUSES),
+    Column("status", Enum(name='zone_transfer_requests_resource_statuses',
+                          *TASK_STATUSES),
            nullable=False, server_default='ACTIVE',
            default='ACTIVE'),
 
@@ -439,7 +441,8 @@ zone_transfer_accepts = Table('zone_transfer_accepts', metadata,
     Column('zone_id', UUID, nullable=False),
     Column('zone_transfer_request_id', UUID, nullable=False),
     Column("tenant_id", String(36), default=None, nullable=False),
-    Column("status", Enum(name='resource_statuses', *TASK_STATUSES),
+    Column("status", Enum(name='zone_transfer_accepts_resource_statuses',
+                          *TASK_STATUSES),
            nullable=False, server_default='ACTIVE',
            default='ACTIVE'),
 
@@ -464,7 +467,7 @@ zone_tasks = Table('zone_tasks', metadata,
     Column('task_type', Enum(name='task_types', *ZONE_TASK_TYPES),
            nullable=True),
     Column('message', String(160), nullable=True),
-    Column('status', Enum(name='resource_statuses', *TASK_STATUSES),
+    Column('status', Enum(name='zone_tasks_resource_statuses', *TASK_STATUSES),
            nullable=False, server_default='ACTIVE',
            default='ACTIVE'),
     Column('location', String(160), nullable=True),
