@@ -519,9 +519,14 @@ class ApiV2ZonesTest(ApiV2TestCase):
 
     def test_update_secondary(self):
         # Create a zone
-        fixture = self.get_zone_fixture('SECONDARY', 0)
-
-        zone = objects.Zone(**fixture)
+        zone = objects.Zone(
+            name='example.com.',
+            type='SECONDARY',
+            masters=objects.ZoneMasterList.from_list([
+                {'host': '1.0.0.0', 'port': 69},
+                {'host': '2.0.0.0', 'port': 69}
+            ])
+        )
         zone.email = cfg.CONF['service:central'].managed_resource_email
 
         # Create a zone
@@ -573,7 +578,7 @@ class ApiV2ZonesTest(ApiV2TestCase):
         # Check the headers are what we expect
         self.assertEqual(202, response.status_int)
         self.assertEqual('application/json', response.content_type)
-        self.assertEqual('""', response.body)
+        self.assertEqual(b'""', response.body)
 
     def test_invalid_xfr_request(self):
         # Create a zone
